@@ -58,7 +58,9 @@ public:
     QByteArray toByteArray();
     Q_INVOKABLE void updateEntryAt(int index, QString name, QString category, QString userName, QString password, QString notes);
 
-    Q_INVOKABLE void importKeePassXml();
+    QList<Entry> getEntryList() const { return m_entries; }
+    void appendEntries(const QList<Entry> entries);
+    Q_INVOKABLE QStringList getItemNames() const;
 
 signals:
     void changed();
